@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_conn.c,v 1.31 2003/04/18 09:03:16 wensong Exp $
+ * Version:     $Id: ip_vs_conn.c,v 1.32 2003/07/05 05:32:36 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -30,6 +30,7 @@
 #include <linux/compiler.h>
 #include <linux/vmalloc.h>
 #include <linux/proc_fs.h>		/* for proc_net_* */
+#include <linux/jhash.h>
 
 #include "ip_vs.h"
 //#include <net/ip_vs.h>
@@ -49,6 +50,8 @@ static atomic_t ip_vs_conn_count = ATOMIC_INIT(0);
 /*  counter for no client port connections */
 static atomic_t ip_vs_conn_no_cport_cnt = ATOMIC_INIT(0);
 
+/* random value for IPVS connection hash */
+static unsigned int ip_vs_conn_rnd;
 
 /*
  *  Fine locking granularity for big connection hash table
@@ -113,10 +116,21 @@ static inline void ct_write_unlock_bh(unsigned key)
 static inline unsigned
 ip_vs_conn_hashkey(unsigned proto, __u32 addr, __u16 port)
 {
-	unsigned addrh = ntohl(addr);
+#ifdef CONFIG_IP_VS_HASH_SHIFTXOR
+	unsigned key = ntohl(addr) + ip_vs_conn_rnd;
 
-	return (proto^addrh^(addrh>>IP_VS_CONN_TAB_BITS)^ntohs(port))
+	key ^= (key >> IP_VS_CONN_TAB_BITS);
+	key ^= (key >> 23);
+	return (proto ^ key ^ ntohs(port)) & IP_VS_CONN_TAB_MASK;
+#endif
+#ifdef CONFIG_IP_VS_HASH_GOLDENRATIO
+	return (((ip_vs_conn_rnd ^ (proto + addr + port)) * 2654435761UL)
+		>> (31 - IP_VS_CONN_TAB_BITS)) & IP_VS_CONN_TAB_MASK;
+#endif
+#ifdef CONFIG_IP_VS_HASH_JENKINS
+	return jhash_3words(addr, port, proto, ip_vs_conn_rnd)
 		& IP_VS_CONN_TAB_MASK;
+#endif
 }
 
 
@@ -714,8 +728,8 @@ void ip_vs_random_dropentry(void)
 	/*
 	 * Randomly scan 1/32 of the whole table every second
 	 */
-	for (idx=0; idx<(IP_VS_CONN_TAB_SIZE>>5); idx++) {
-		unsigned hash = net_random()&IP_VS_CONN_TAB_MASK;
+	for (idx = 0; idx < (IP_VS_CONN_TAB_SIZE>>5); idx++) {
+		unsigned hash = net_random() & IP_VS_CONN_TAB_MASK;
 
 		/*
 		 *  Lock is actually needed in this loop.
@@ -851,6 +865,11 @@ int ip_vs_conn_init(void)
 
 	proc_net_create("ip_vs_conn", 0, ip_vs_conn_getinfo);
 
+	/* calculate the random value for connection hash */
+	ip_vs_conn_rnd =
+		jhash_3words((u32) jiffies, (u32) ip_vs_conn_tab,
+			     net_random(), IP_VS_CONN_TAB_SIZE);
+
 	return 0;
 }
 
