@@ -1,7 +1,7 @@
 /*
  * IPVS:        Destination Hashing scheduling module
  *
- * Version:     $Id: ip_vs_dh.c,v 1.3 2001/05/09 15:01:15 wensong Exp $
+ * Version:     $Id: ip_vs_dh.c,v 1.5 2002/09/15 08:14:08 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@gnuchina.org>
  *
@@ -23,7 +23,7 @@
  *
  *       n <- servernode[dest_ip];
  *       if (n is dead) OR
- *          (n is overloaded, such as n.conns>2*n.weight) then
+ *          (n is overloaded) OR (n.weight <= 0) then
  *                 return NULL;
  *
  *       return n;
@@ -190,15 +190,12 @@ static int ip_vs_dh_update_svc(struct ip_vs_service *svc)
 
 
 /*
- *      If the number of active connections is twice larger than its weight,
+ *      If the dest flags is set with IP_VS_DEST_F_OVERLOAD,
  *      consider that the server is overloaded here.
  */
 static inline int is_overloaded(struct ip_vs_dest *dest)
 {
-	if (atomic_read(&dest->activeconns) > atomic_read(&dest->weight)*2) {
-		return 1;
-	}
-	return 0;
+	return dest->flags & IP_VS_DEST_F_OVERLOAD;
 }
 
 
@@ -237,14 +234,13 @@ ip_vs_dh_schedule(struct ip_vs_service *svc, struct iphdr *iph)
  */
 static struct ip_vs_scheduler ip_vs_dh_scheduler =
 {
-	{0},                    /* n_list */
-	"dh",                   /* name */
-	ATOMIC_INIT(0),         /* refcnt */
-	THIS_MODULE,            /* this module */
-	ip_vs_dh_init_svc,      /* service initializer */
-	ip_vs_dh_done_svc,      /* service done */
-	ip_vs_dh_update_svc,    /* service updater */
-	ip_vs_dh_schedule,      /* select a server from the destination list */
+	.name =			"dh",
+	.refcnt =		ATOMIC_INIT(0),
+	.module =		THIS_MODULE,
+	.init_service =		ip_vs_dh_init_svc,
+	.done_service =		ip_vs_dh_done_svc,
+	.update_service =	ip_vs_dh_update_svc,
+	.schedule =		ip_vs_dh_schedule,
 };
 
 
@@ -263,3 +259,4 @@ static void __exit ip_vs_dh_cleanup(void)
 
 module_init(ip_vs_dh_init);
 module_exit(ip_vs_dh_cleanup);
+MODULE_LICENSE("GPL");
