@@ -1,7 +1,7 @@
 /*
- * ip_vs_est.c  Simple rate estimator for IPVS
+ * ip_vs_est.c: simple rate estimator for IPVS
  *
- * Version:     $Id: ip_vs_est.c,v 1.3.2.1 2003/07/29 14:37:13 wensong Exp $
+ * Version:     $Id: ip_vs_est.c,v 1.4 2002/11/30 01:50:35 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -78,8 +78,6 @@ static void estimation_timer(unsigned long arg)
 	read_lock(&est_lock);
 	for (e = est_list; e; e = e->next) {
 		s = e->stats;
-
-		spin_lock(&s->lock);
 		n_conns = s->conns;
 		n_inpkts = s->inpkts;
 		n_outpkts = s->outpkts;
@@ -111,7 +109,6 @@ static void estimation_timer(unsigned long arg)
 		e->last_outbytes = n_outbytes;
 		e->outbps += ((long)rate - (long)e->outbps)>>2;
 		s->outbps = (e->outbps+0xF)>>5;
-		spin_unlock(&s->lock);
 	}
 	read_unlock(&est_lock);
 	mod_timer(&est_timer, jiffies + 2*HZ);
@@ -142,6 +139,7 @@ int ip_vs_new_estimator(struct ip_vs_stats *stats)
 	est->last_outbytes = stats->outbytes;
 	est->outbps = stats->outbps<<5;
 
+	write_lock_bh(&est_lock);
 	est->next = est_list;
 	if (est->next == NULL) {
 		init_timer(&est_timer);
@@ -149,7 +147,6 @@ int ip_vs_new_estimator(struct ip_vs_stats *stats)
 		est_timer.function = estimation_timer;
 		add_timer(&est_timer);
 	}
-	write_lock_bh(&est_lock);
 	est_list = est;
 	write_unlock_bh(&est_lock);
 	return 0;
