@@ -1,7 +1,7 @@
 /*
  * IPVS:        Least-Connection Scheduling module
  *
- * Version:     $Id: ip_vs_lc.c,v 1.9 2002/09/15 08:14:08 wensong Exp $
+ * Version:     $Id: ip_vs_lc.c,v 1.10 2003/04/18 09:03:16 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -45,15 +45,30 @@ static int ip_vs_lc_update_svc(struct ip_vs_service *svc)
 }
 
 
+static inline unsigned int
+ip_vs_lc_dest_overhead(struct ip_vs_dest *dest)
+{
+	/*
+	 * We think the overhead of processing active connections is 256
+	 * times higher than that of inactive connections in average. (This
+	 * 256 times might not be accurate, we will change it later) We
+	 * use the following formula to estimate the overhead now:
+	 *		  dest->activeconns*256 + dest->inactconns
+	 */
+	return (atomic_read(&dest->activeconns) << 8) +
+		atomic_read(&dest->inactconns);
+}
+
+
 /*
- *    Least Connection scheduling
+ *	Least Connection scheduling
  */
 static struct ip_vs_dest *
 ip_vs_lc_schedule(struct ip_vs_service *svc, struct iphdr *iph)
 {
 	struct list_head *l, *e;
 	struct ip_vs_dest *dest, *least;
-	int lac, dac;
+	unsigned int loh, doh;
 
 	IP_VS_DBG(6, "ip_vs_lc_schedule(): Scheduling...\n");
 
@@ -72,8 +87,7 @@ ip_vs_lc_schedule(struct ip_vs_service *svc, struct iphdr *iph)
 		if (least->flags & IP_VS_DEST_F_OVERLOAD)
 			continue;
 		if (atomic_read(&least->weight) > 0) {
-			lac = (atomic_read(&least->activeconns) << 5)
-				+ atomic_read(&least->inactconns);
+			loh = ip_vs_lc_dest_overhead(least);
 			goto nextstage;
 		}
 	}
@@ -88,11 +102,10 @@ ip_vs_lc_schedule(struct ip_vs_service *svc, struct iphdr *iph)
 		if ((dest->flags & IP_VS_DEST_F_OVERLOAD) ||
 		    atomic_read(&dest->weight) == 0)
 			continue;
-		dac = (atomic_read(&dest->activeconns) << 5)
-			+ atomic_read(&dest->inactconns);
-		if (dac < lac) {
+		doh = ip_vs_lc_dest_overhead(dest);
+		if (doh < loh) {
 			least = dest;
-			lac = dac;
+			loh = doh;
 		}
 	}
 
