@@ -1,7 +1,7 @@
 /*
  * IPVS:        Source Hashing scheduling module
  *
- * Version:     $Id: ip_vs_sh.c,v 1.4 2001/10/19 15:05:17 wensong Exp $
+ * Version:     $Id: ip_vs_sh.c,v 1.5 2002/09/15 08:14:08 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@gnuchina.org>
  *
@@ -20,7 +20,7 @@
  *
  *       n <- servernode[src_ip];
  *       if (n is dead) OR
- *          (n is overloaded, such as n.conns>2*n.weight) then
+ *          (n is overloaded) or (n.weight <= 0) then
  *                 return NULL;
  *
  *       return n;
@@ -187,15 +187,12 @@ static int ip_vs_sh_update_svc(struct ip_vs_service *svc)
 
 
 /*
- *      If the number of active connections is twice larger than its weight,
+ *      If the dest flags is set with IP_VS_DEST_F_OVERLOAD,
  *      consider that the server is overloaded here.
  */
 static inline int is_overloaded(struct ip_vs_dest *dest)
 {
-	if (atomic_read(&dest->activeconns) > atomic_read(&dest->weight)*2) {
-		return 1;
-	}
-	return 0;
+	return dest->flags & IP_VS_DEST_F_OVERLOAD;
 }
 
 
@@ -234,14 +231,13 @@ ip_vs_sh_schedule(struct ip_vs_service *svc, struct iphdr *iph)
  */
 static struct ip_vs_scheduler ip_vs_sh_scheduler =
 {
-	{0},                    /* n_list */
-	"sh",                   /* name */
-	ATOMIC_INIT(0),         /* refcnt */
-	THIS_MODULE,            /* this module */
-	ip_vs_sh_init_svc,      /* service initializer */
-	ip_vs_sh_done_svc,      /* service done */
-	ip_vs_sh_update_svc,    /* service updater */
-	ip_vs_sh_schedule,      /* select a server from the destination list */
+	.name =			"sh",
+	.refcnt =		ATOMIC_INIT(0),
+	.module =		THIS_MODULE,
+	.init_service =		ip_vs_sh_init_svc,
+	.done_service =		ip_vs_sh_done_svc,
+	.update_service =	ip_vs_sh_update_svc,
+	.schedule =		ip_vs_sh_schedule,
 };
 
 
