@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_sync.c,v 1.13 2003/06/08 09:31:19 wensong Exp $
+ * Version:     $Id: ip_vs_sync.c,v 1.14 2003/07/05 05:32:36 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -293,7 +293,7 @@ static void ip_vs_process_message(const char *buffer, const size_t buflen)
 	}
 
 	/* SyncID sanity check */
-	if (ip_vs_backup_syncid != 255 && m->syncid != ip_vs_backup_syncid) {
+	if (ip_vs_backup_syncid != 0 && m->syncid != ip_vs_backup_syncid) {
 		IP_VS_DBG(7, "Ignoring incoming msg with syncid = %d\n",
 			  m->syncid);
 		return;
@@ -379,7 +379,7 @@ static int set_mcast_if(struct sock *sk, char *ifname)
 	if ((dev = __dev_get_by_name(ifname)) == NULL)
 		return -ENODEV;
 
-	if (sk->bound_dev_if && dev->ifindex != sk->bound_dev_if)
+	if (sk->sk_bound_dev_if && dev->ifindex != sk->sk_bound_dev_if)
 		return -EINVAL;
 
 	lock_sock(sk);
@@ -442,7 +442,7 @@ join_mcast_group(struct sock *sk, struct in_addr *addr, char *ifname)
 
 	if ((dev = __dev_get_by_name(ifname)) == NULL)
 		return -ENODEV;
-	if (sk->bound_dev_if && dev->ifindex != sk->bound_dev_if)
+	if (sk->sk_bound_dev_if && dev->ifindex != sk->sk_bound_dev_if)
 		return -EINVAL;
 
 	mreq.imr_ifindex = dev->ifindex;
@@ -535,7 +535,7 @@ static struct socket * make_receive_sock(void)
 	}
 
 	/* it is equivalent to the REUSEADDR option in user-space */
-	sock->sk->reuse = 1;
+	sock->sk->sk_reuse = 1;
 
 	if (sock->ops->bind(sock,
 			    (struct sockaddr*)&mcast_addr,
@@ -709,7 +709,7 @@ static void sync_backup_loop(void)
 
 	for (;;) {
 		/* do you have data now? */
-		while (!skb_queue_empty(&(sock->sk->receive_queue))) {
+		while (!skb_queue_empty(&(sock->sk->sk_receive_queue))) {
 			if ((len =
 			     ip_vs_receive(sock, buf,
 					   sync_recv_mesg_maxlen)) <= 0) {
@@ -857,10 +857,10 @@ int start_sync_thread(int state, char *mcast_ifn, __u8 syncid)
 	ip_vs_sync_state |= state;
 	if (state == IP_VS_STATE_MASTER) {
 		strcpy(ip_vs_master_mcast_ifn, mcast_ifn);
-		ip_vs_master_syncid = (syncid) ? syncid : 255;
+		ip_vs_master_syncid = syncid;
 	} else {
 		strcpy(ip_vs_backup_mcast_ifn, mcast_ifn);
-		ip_vs_backup_syncid = (syncid) ? syncid : 255;
+		ip_vs_backup_syncid = syncid;
 	}
 
 	if ((pid = kernel_thread(fork_sync_thread, &startup, 0)) < 0)
