@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_timer.c,v 1.10 2003/03/22 06:31:21 wensong Exp $
+ * Version:     $Id: ip_vs_timer.c,v 1.11 2003/06/08 09:31:19 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Julian Anastasov <ja@ssi.bg>
@@ -241,13 +241,17 @@ static void sltimer_handler(unsigned long data)
 
 void ip_vs_sltimer_init(void)
 {
-	/*
-	 * Hook the slow_timer handler in the system timer.
-	 */
+	/* initialize the slow timer vectors */
 	init_sltimervecs();
 
+	/* initialize the slow timer jiffies and the vector indexes */
 	sltimer_jiffies = jiffies;
+	sltv1.index = (sltimer_jiffies >> SHIFT_BITS) & TVR_MASK;
+	sltv2.index = (sltimer_jiffies >> (SHIFT_BITS + TVR_BITS)) & TVN_MASK;
+	sltv3.index = (sltimer_jiffies >> (SHIFT_BITS + TVR_BITS + TVN_BITS))
+		& TVN_MASK;
 
+	/* Hook the slow_timer handler in the system timer */
 	init_timer(&slow_timer);
 	slow_timer.function = sltimer_handler;
 	slow_timer.expires = jiffies+SLTIMER_PERIOD;
