@@ -1,7 +1,7 @@
 /*
  * IPVS:        Weighted Least-Connection Scheduling module
  *
- * Version:     $Id: ip_vs_wlc.c,v 1.12 2003/03/22 06:31:21 wensong Exp $
+ * Version:     $Id: ip_vs_wlc.c,v 1.13 2003/04/18 09:03:16 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -53,15 +53,23 @@ ip_vs_wlc_update_svc(struct ip_vs_service *svc)
 }
 
 
-static unsigned int
+static inline unsigned int
 ip_vs_wlc_dest_overhead(struct ip_vs_dest *dest)
 {
+	/*
+	 * We think the overhead of processing active connections is 256
+	 * times higher than that of inactive connections in average. (This
+	 * 256 times might not be accurate, we will change it later) We
+	 * use the following formula to estimate the overhead now:
+	 *		  dest->activeconns*256 + dest->inactconns
+	 */
 	return (atomic_read(&dest->activeconns) << 8) +
 		atomic_read(&dest->inactconns);
 }
 
+
 /*
- *    Weighted Least Connection scheduling
+ *	Weighted Least Connection scheduling
  */
 static struct ip_vs_dest *
 ip_vs_wlc_schedule(struct ip_vs_service *svc, struct iphdr *iph)
@@ -73,12 +81,7 @@ ip_vs_wlc_schedule(struct ip_vs_service *svc, struct iphdr *iph)
 	IP_VS_DBG(6, "ip_vs_wlc_schedule(): Scheduling...\n");
 
 	/*
-	 * We think the overhead of processing active connections is 256
-	 * times higher than that of inactive connections in average. (This
-	 * 256 times might not be accurate, we will change it later.) We
-	 * use the following formula to estimate the overhead:
-	 *		  dest->activeconns*256 + dest->inactconns
-	 * and the load:
+	 * We calculate the load of each dest server as follows:
 	 *		  (dest overhead) / dest->weight
 	 *
 	 * Remember -- no floats in kernel mode!!!
