@@ -1,7 +1,7 @@
 /*
  * IPVS:        Weighted Round-Robin Scheduling module
  *
- * Version:     $Id: ip_vs_wrr.c,v 1.11 2002/03/25 12:44:35 wensong Exp $
+ * Version:     $Id: ip_vs_wrr.c,v 1.12 2002/09/15 08:14:08 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -157,22 +157,24 @@ ip_vs_wrr_schedule(struct ip_vs_service *svc, struct iphdr *iph)
 {
 	struct ip_vs_dest *dest;
 	struct ip_vs_wrr_mark *mark = svc->sched_data;
+	struct list_head *p;
 
 	IP_VS_DBG(6, "ip_vs_wrr_schedule(): Scheduling...\n");
 
 	/*
-	 * This loop will always terminate, because 0<mark->cw<max_weight,
+	 * This loop will always terminate, because mark->cw in (0, max_weight]
 	 * and at least one server has its weight equal to max_weight.
 	 */
 	write_lock(&svc->sched_lock);
+	p = mark->cl;
 	while (1) {
 		if (mark->cl == &svc->destinations) {
 			/* it is at the head of the destination list */
 
 			if (mark->cl == mark->cl->next) {
 				/* no dest entry */
-				write_unlock(&svc->sched_lock);
-				return NULL;
+				dest = NULL;
+				goto out;
 			}
 
 			mark->cl = svc->destinations.next;
@@ -184,23 +186,31 @@ ip_vs_wrr_schedule(struct ip_vs_service *svc, struct iphdr *iph)
 				 */
 				if (mark->cw == 0) {
 					mark->cl = &svc->destinations;
-					write_unlock(&svc->sched_lock);
 					IP_VS_INFO("ip_vs_wrr_schedule(): "
 						   "no available servers\n");
-					return NULL;
+					dest = NULL;
+					goto out;
 				}
 			}
-		}
-		else mark->cl = mark->cl->next;
+		} else
+			mark->cl = mark->cl->next;
 
 		if (mark->cl != &svc->destinations) {
 			/* not at the head of the list */
 			dest = list_entry(mark->cl, struct ip_vs_dest, n_list);
-			if (atomic_read(&dest->weight) >= mark->cw) {
-				write_unlock(&svc->sched_lock);
+			if (!(dest->flags & IP_VS_DEST_F_OVERLOAD) &&
+			    atomic_read(&dest->weight) >= mark->cw) {
+				/* got it */
 				break;
 			}
 		}
+
+		if (mark->cl == p) {
+			/* back to the start, and no dest is found.
+			   It is only possible when all dests are OVERLOADED */
+			dest = NULL;
+			goto out;
+		}
 	}
 
 	IP_VS_DBG(6, "WRR: server %u.%u.%u.%u:%u "
@@ -210,19 +220,20 @@ ip_vs_wrr_schedule(struct ip_vs_service *svc, struct iphdr *iph)
 		  atomic_read(&dest->refcnt),
 		  atomic_read(&dest->weight));
 
-	return	dest;
+  out:
+	write_unlock(&svc->sched_lock);
+	return dest;
 }
 
 
 static struct ip_vs_scheduler ip_vs_wrr_scheduler = {
-	{0},			/* n_list */
-	"wrr",			/* name */
-	ATOMIC_INIT(0),		/* refcnt */
-	THIS_MODULE,		/* this module */
-	ip_vs_wrr_init_svc,	/* service initializer */
-	ip_vs_wrr_done_svc,	/* service done */
-	ip_vs_wrr_update_svc,	/* service updater */
-	ip_vs_wrr_schedule,	/* select a server from the destination list */
+	.name =			"wrr",
+	.refcnt =		ATOMIC_INIT(0),
+	.module =		THIS_MODULE,
+	.init_service =		ip_vs_wrr_init_svc,
+	.done_service =		ip_vs_wrr_done_svc,
+	.update_service =	ip_vs_wrr_update_svc,
+	.schedule =		ip_vs_wrr_schedule,
 };
 
 static int __init ip_vs_wrr_init(void)
